==> vtk6-6.3.0-9-aarch64.pkg.tar.xz: vtk/vtkExporter.java <==
// java wrapper for vtkExporter object
//

package vtk;
import vtk.*;

public class vtkExporter extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Write_2();
  public void Write()
    { Write_2(); }

  private native void Update_3();
  public void Update()
    { Update_3(); }

  private native void SetRenderWindow_4(vtkRenderWindow id0);
  public void SetRenderWindow(vtkRenderWindow id0)
    { SetRenderWindow_4(id0); }

  private native long GetRenderWindow_5();
  public vtkRenderWindow GetRenderWindow() {
    long temp = GetRenderWindow_5();

    if (temp == 0) return null;
    return (vtkRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetInput_6(vtkRenderWindow id0);
  public void SetInput(vtkRenderWindow id0)
    { SetInput_6(id0); }

  private native long GetInput_7();
  public vtkRenderWindow GetInput() {
    long temp = GetInput_7();

    if (temp == 0) return null;
    return (vtkRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetStartWrite_8(Object id0, String id1);
  public void SetStartWrite(Object id0, String id1)
    { SetStartWrite_8(id0,id1); }

  private native void SetEndWrite_9(Object id0, String id1);
  public void SetEndWrite(Object id0, String id1)
    { SetEndWrite_9(id0,id1); }

  private native int GetMTime_10();
  public int GetMTime()
    { return GetMTime_10(); }

  public vtkExporter() { super(); }

  public vtkExporter(long id) { super(id); }

}

==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkExporter.java <==
// java wrapper for vtkExporter object
//

package vtk;
import vtk.*;

public class vtkExporter extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Write_2();
  public void Write()
    { Write_2(); }

  private native void Update_3();
  public void Update()
    { Update_3(); }

  private native void SetRenderWindow_4(vtkRenderWindow id0);
  public void SetRenderWindow(vtkRenderWindow id0)
    { SetRenderWindow_4(id0); }

  private native long GetRenderWindow_5();
  public vtkRenderWindow GetRenderWindow() {
    long temp = GetRenderWindow_5();

    if (temp == 0) return null;
    return (vtkRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInput_6(vtkRenderWindow id0);
  public void SetInput(vtkRenderWindow id0)
    { SetInput_6(id0); }

  private native long GetInput_7();
  public vtkRenderWindow GetInput() {
    long temp = GetInput_7();

    if (temp == 0) return null;
    return (vtkRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetStartWrite_8(Object id0, String id1);
  public void SetStartWrite(Object id0, String id1)
    { SetStartWrite_8(id0,id1); }

  private native void SetEndWrite_9(Object id0, String id1);
  public void SetEndWrite(Object id0, String id1)
    { SetEndWrite_9(id0,id1); }

  private native int GetMTime_10();
  public int GetMTime()
    { return GetMTime_10(); }

  public vtkExporter() { super(); }

  public vtkExporter(long id) { super(id); }

}
